Users — bodhi 3.1.0 documentation

# Users

## User service at /users/{name}

Bodhi users

### GET

Accepted content types:

- text/html

Return a user given by username.

Args:
  request (pyramid.request): The current request.
Returns:
  dict: A dictionary with two keys. “user” maps to a dictionary representation of the User
    object. “urls” maps to various URLs that describe various other objects related to the user.

Response: user.html

### GET

Accepted content types:

- application/javascript

Return a user given by username.

Args:
  request (pyramid.request): The current request.
Returns:
  dict: A dictionary with two keys. “user” maps to a dictionary representation of the User
    object. “urls” maps to various URLs that describe various other objects related to the user.

Response: jsonp

### GET

Accepted content types:

- application/json
- text/json

Return a user given by username.

Args:
  request (pyramid.request): The current request.
Returns:
  dict: A dictionary with two keys. “user” maps to a dictionary representation of the User
    object. “urls” maps to various URLs that describe various other objects related to the user.

Response: json

## Users service at /users/

Bodhi users

### GET

values in the querystring

- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- name (String) - (optional)
- groups (Sequence) - (optional)
- updates (Sequence) - (optional)
- packages (Sequence) - (optional)

Accepted content types:

- application/atom+xml

Search for users by various criteria.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: A dictionary with the follow key mappings:
    users: A list of users matching the search criteria. page: The current page of results. pages: The total number of pages available. rows_per_page: The number of users on the page. total: The total number of users matching the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure the referenced groups exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced updates exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: rss

### GET

values in the querystring

- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- name (String) - (optional)
- groups (Sequence) - (optional)
- updates (Sequence) - (optional)
- packages (Sequence) - (optional)

Accepted content types:

- application/javascript

Search for users by various criteria.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: A dictionary with the follow key mappings:
    users: A list of users matching the search criteria. page: The current page of results. pages: The total number of pages available. rows_per_page: The number of users on the page. total: The total number of users matching the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure the referenced groups exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced updates exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: jsonp

### GET

values in the querystring

- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- name (String) - (optional)
- groups (Sequence) - (optional)
- updates (Sequence) - (optional)
- packages (Sequence) - (optional)

Accepted content types:

- application/json
- text/json

Search for users by various criteria.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: A dictionary with the follow key mappings:
    users: A list of users matching the search criteria. page: The current page of results. pages: The total number of pages available. rows_per_page: The number of users on the page. total: The total number of users matching the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure the referenced groups exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced updates exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: json

## Users_Rss service at /rss/users/

Bodhi users RSS feed

### GET

values in the querystring

- like (String) - (optional)
- search (String) - (optional)
- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- name (String) - (optional)
- groups (Sequence) - (optional)
- updates (Sequence) - (optional)
- packages (Sequence) - (optional)

Search for users by various criteria.

Args:
  request (pyramid.request): The current web request.
Returns:
  dict: A dictionary with the follow key mappings:
    users: A list of users matching the search criteria. page: The current page of results. pages: The total number of pages available. rows_per_page: The number of users on the page. total: The total number of users matching the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure the referenced groups exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced updates exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: rss